glue\_genes.glue\_genomics\_data.ome\_zarr\_factory.read\_ome\_zarr
===================================================================

.. currentmodule:: glue_genes.glue_genomics_data.ome_zarr_factory

.. autofunction:: read_ome_zarr